﻿// Disclaimer:
// This software is provided AS IS for educational purposes only,
// with no warranties, and confers no rights. Error checking is 
// elided for clarity. Carry out sufficient tests prior to using
// it in a productive environment.
// CASIO Europe GmbH accepts no responsibility for loss or damage
// arising from its use, including damage from virus.
//
// Please, note: This configuration information may be changed
// without any further notice.
// Casio Europe GmbH does not guarantee future compatibility. By 
// using this software you agree to these terms and conditions.
//
// Version 1.00 - January 11, 2012
// Supported Devices: IT-300, IT-800
//
// Remarks: You need latest versions of CASIO runtime libraries on
// your mobile device. If they are not already installed, you can 
// find them as part of the SDK.
//////////////////////////////////////////////////////////////////////

using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using Microsoft.WindowsCE.Forms;
using Calib;

namespace VirtualOff
{
    public partial class MainForm : Form
    {
        private PowerBroadcast powerBroadcast;
        private const int MaxWait = 3000;
        private const int MaxEntries = 20;

        public MainForm()
        {
            InitializeComponent();

            this.powerBroadcast = new PowerBroadcast(this);
            VirtualOffEnable();
        }

        private void MainForm_Closing(object sender, CancelEventArgs e)
        {
            VirtualOffDisable();
        }

        private void menuExit_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void menuClear_Click(object sender, EventArgs e)
        {
            this.lbxMessages.Items.Clear();
        }

        private void VirtualOffEnable()
        {
            AddEntry("VirtualOffEnable");
            SystemLibNet.Api.SysSetVirtualOffMode(SystemLibNet.Def.VIRTUALOFF_ENABLE);
            SystemLibNet.Api.SysDisablePowerOff();
            if (SystemLibNet.Api.SysGetAPO() == 0)
            {
                SystemLibNet.Api.SysDisableAPO();
            }
        }

        private void VirtualOffDisable()
        {
            AddEntry("VirtualOffDisable");
            SystemLibNet.Api.SysSetVirtualOffMode(SystemLibNet.Def.VIRTUALOFF_DISABLE);
            SystemLibNet.Api.SysEnablePowerOff();
            if (SystemLibNet.Api.SysGetAPO() != 0)
            {
                SystemLibNet.Api.SysEnableAPO();
            }
        }

        private void VirtualOff()
        {
            AddEntry("VirtualOff");
            SystemLibNet.Api.SysDisplayOff();
            SystemLibNet.Api.SysSetAllKeyLock(true);
        }

        private void VirtualOn()
        {
            AddEntry("VirtualOn");
            SystemLibNet.Api.SysDisplayOn();
            SystemLibNet.Api.SysSetAllKeyLock(false);
        }

        public void OnResumeSuspend()
        {
            AddEntry("OnResumeSuspend");
            int powerOff = SystemLibNet.Api.SysGetPowerOff();
            if (powerOff == 0) // Battery empty, battery cover opened, etc...
            {
                Thread.Sleep(MaxWait);
                VirtualOffEnable();
            }
            else
            {
                VirtualOn();
            }
        }

        public void OnBatteryLow()
        {
            AddEntry("OnBatteryLow");
            SystemLibNet.Api.SysPowerOff();
        }

        public void OnSuspend()
        {
            AddEntry("OnSuspend");
            VirtualOff();
        }

        private void AddEntry(string theEntry)
        {
            while (this.lbxMessages.Items.Count >= MaxEntries)
            {
                this.lbxMessages.Items.RemoveAt(0);
            }

            int index = this.lbxMessages.Items.Add(theEntry);
            if (index != -1)
            {
                this.lbxMessages.SelectedIndex = index;
            }
        }
    }
}